@@ -49,6 +49,17 @@ func NewSymbolMap() SymbolMap {
 	return make(SymbolMap)
 }
 
+func (sm SymbolMap) LoadJSON(infile string) error {
+	data, err := os.ReadFile(infile)
+	if err != nil {
+		return fmt.Errorf("failed to read file: %v", err)
+	}
+	if err := json.Unmarshal(data, &sm); err != nil {
+		return fmt.Errorf("failed to unmarshal json: %v", err)
+	}
+	return nil
+}
+
 func (sm SymbolMap) Add(addr uint64, symbol string) error {
 	if sym, ok := sm[addr]; ok {
 		if sym == symbol || sym == symbol+"_trap" {
@@ -232,6 +243,26 @@ func (sm SymbolMap) getMachTraps(m *macho.File) error {
 	return nil
 }
 
+func (sm SymbolMap) getMig(m *macho.File) error {
+	migs, err := kernelcache.GetMigSubsystems(m)
+	if err != nil {
+		return fmt.Errorf("failed to get MIG subsystems: %v", err)
+	}
+
+	for _, mig := range migs {
+		if err := sm.Add(mig.KServer, strings.TrimSuffix(mig.Start.String(), "_subsystem")+"_server_routine"); err != nil {
+			utils.Indent(log.WithError(err).Debug, 2)("Adding mig server_routine")
+		}
+		for idx, routine := range mig.Routines {
+			if err := sm.Add(routine.KStubRoutine, mig.LookupRoutineName(idx)); err != nil {
+				utils.Indent(log.WithError(err).Debug, 2)("Adding mig routine")
+			}
+		}
+	}
+
+	return nil
+}
+
 func (sm SymbolMap) Symbolicate(infile string, sigs []Symbolicator, quiet bool) error {
 	kc, err := macho.Open(infile)
 	if err != nil {
@@ -245,10 +276,13 @@ func (sm SymbolMap) Symbolicate(infile string, sigs []Symbolicator, quiet bool)
 	}
 
 	if err := sm.getSyscalls(kc); err != nil {
-		return err
+		log.WithError(err).Warn("failed to get syscalls")
 	}
 	if err := sm.getMachTraps(kc); err != nil {
-		return err
+		log.WithError(err).Warn("failed to get mach traps")
+	}
+	if err := sm.getMig(kc); err != nil {
+		log.WithError(err).Warn("failed to get MIG subsystems")
 	}
 
 	goodsig := false
